pub struct FuelValuesBuilder {
burn_durations: Vec<i32>,
}Expand description
Mutable construction phase for FuelValues.
Fields
burn_durations: Vec<i32>Implementations
Sourceimpl FuelValuesBuilder
impl FuelValuesBuilder
Sourcepub fn add_tag(self, tag: &Identifier, burn_duration: i32) -> Self
pub fn add_tag(self, tag: &Identifier, burn_duration: i32) -> Self
Assigns every item in a tag a burn duration.
Sourcepub fn remove_tag(self, tag: &Identifier) -> Self
pub fn remove_tag(self, tag: &Identifier) -> Self
Removes every item in a tag from the table.
Sourcepub fn build(self) -> FuelValues
pub fn build(self) -> FuelValues
Finishes the immutable table.
fn put(&mut self, item: &'static Item, burn_duration: i32)